<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LineBisector</name>
    <message>
        <location filename="../LineBisector.js" line="+66"/>
        <source>First line</source>
        <translation>第一条线</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Second line</source>
        <translation>第二条线</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Lines don&apos;t intersect.</source>
        <translation>线不交叉.</translation>
    </message>
    <message>
        <location filename="../LineBisector.ui" line="+17"/>
        <source>Length:</source>
        <translation>长度：</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <location filename="../LineBisectorInit.js" line="+2"/>
        <source>Angle &amp;Bisector</source>
        <translation>角平分线(&amp;B)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw angle bisector, trisector, ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
